"use strict";
var colors_1 = require('./colors');
exports.ColorPalette = colors_1.ColorPalette;
var BufferedOutput = (function () {
    function BufferedOutput(dataStream, lineWrapper, flushTimeout) {
        if (flushTimeout === void 0) { flushTimeout = 250; }
        this.flushTimeout = 250;
        this._lineBuffer = [];
        this._bufferTimeout = 0;
        this.dataStream = dataStream;
        this.flushTimeout = flushTimeout;
        this.lineWrapper = lineWrapper;
        this.dataStream.on('data', this.handleData.bind(this));
        this.dataStream.on('close', this.flush.bind(this));
    }
    BufferedOutput.prototype.handleData = function (data) {
        var _this = this;
        data
            .toString()
            .trim()
            .split(/\n/g)
            .map(this.lineWrapper.bind(this))
            .forEach(function (l) { return _this._lineBuffer.push(l); });
        clearTimeout(this._bufferTimeout);
        if (this._lineBuffer.length > BufferedOutput.MAX_BUFFER_LINES) {
            this.flush();
            return;
        }
        this._bufferTimeout = setTimeout(this.flush.bind(this), this.flushTimeout);
    };
    BufferedOutput.prototype.flush = function () {
        if (!this._lineBuffer.length) {
            return;
        }
        console.log(this._lineBuffer.join('\n'));
        this._lineBuffer = [];
    };
    BufferedOutput.prototype.done = function () {
        clearTimeout(this._bufferTimeout);
        this.flush();
    };
    BufferedOutput.MAX_BUFFER_LINES = 10;
    return BufferedOutput;
}());
exports.BufferedOutput = BufferedOutput;
